@@ -169,6 +169,11 @@ class LaunchPad(FWSerializable):
         if isinstance(wf, FireWork):
             wf = Workflow.from_FireWork(wf)
 
+        # sets the root FWs as READY
+        # prefer to wf.refresh() for speed reasons w/many root FWs
+        for fw_id in wf.root_fw_ids:
+            wf.id_fw[fw_id].state = 'READY'
+
         # insert the FireWorks and get back mapping of old to new ids
         old_new = self._upsert_fws(list(wf.id_fw.values()), reassign_all=reassign_all)
 
@@ -176,12 +181,7 @@ class LaunchPad(FWSerializable):
         wf._reassign_ids(old_new)
 
         # insert the WFLinks
-        # make the first part query something that always returns False so we can use f&modify
-        self.workflows.find_and_modify({'_id': -1}, wf.to_db_dict(), upsert=True)
-
-        # refresh WF states, starting from all roots
-        for fw_id in wf.root_fw_ids:
-            self._refresh_wf(wf, fw_id)
+        self.workflows.insert(wf.to_db_dict())
 
         self.m_logger.info('Added a workflow. id_map: {}'.format(old_new))
         return old_new
@@ -695,7 +695,7 @@ class LaunchPad(FWSerializable):
     def rerun_fw(self, fw_id):
         wf = self.get_wf_by_fw_id(fw_id)
         updated_ids = wf.rerun_fw(fw_id)
-        self._upsert_wf(wf, updated_ids)
+        self._update_wf(wf, updated_ids)
 
     def _refresh_wf(self, wf, fw_id):
 
@@ -708,15 +708,24 @@ class LaunchPad(FWSerializable):
         # TODO: need a try-except here, high probability of failure if incorrect action supplied
 
         updated_ids = wf.refresh(fw_id)
-        self._upsert_wf(wf, updated_ids)
+        self._update_wf(wf, updated_ids)
 
 
-    def _upsert_wf(self, wf, updated_ids):
+    def _update_wf(self, wf, updated_ids):
         updated_fws = [wf.id_fw[fid] for fid in updated_ids]
         old_new = self._upsert_fws(updated_fws)
         wf._reassign_ids(old_new)
-        # redo the links - note that if you don't search across all keys, you can get errors
-        self.workflows.find_and_modify({'nodes': {'$in': list(wf.id_fw.keys())}}, wf.to_db_dict())
+
+        # find a node for which the id did not change, so we can query on it to get WF
+        query_node = None
+        for f in wf.id_fw:
+            if f not in old_new or old_new[f] == f:
+                query_node = f
+                break
+
+        assert query_node is not None
+        # redo the links
+        self.workflows.find_and_modify({'nodes': query_node}, wf.to_db_dict())
 
 
     def _steal_launches(self, thief_fw):
