@@ -51,17 +51,17 @@ class FileDeleteTask(FireTaskBase):
 
 class FileTransferTask(FireTaskBase):
     """
-    A FireTask to Transfer files:
+    A FireTask to Transfer files. Note that
     Required params:
         - mode: (str) - move, mv, copy, cp, copy2, copytree, copyfile, rtransfer
-        - files: ([str]) - source files
-        - dest: (str) destination directory
+        - files: ([str]) or ([(str, str)]) - list of source files, or dictionary containing 'src' and 'dest' keys
+        - dest: (str) destination directory, if not specified within files parameter
     Optional params:
         - server: (str) server host for remote transfer
         - key_filename: (str) optional SSH key location for remote transfer
     """
     _fw_name = 'FileTransferTask'
-    required_params = ["mode", "files", "dest"]
+    required_params = ["mode", "files"]
 
     fn_list = {
             "move": shutil.move,
@@ -89,7 +89,11 @@ class FileTransferTask(FireTaskBase):
 
         for f in self["files"]:
             try:
-                src = abspath(expanduser(expandvars(f))) if shell_interpret else f
+                if 'src' in f:
+                    src = os.path.abspath(expanduser(expandvars(f['src']))) if shell_interpret \
+                        else f['src']
+                else:
+                    src = abspath(expanduser(expandvars(f))) if shell_interpret else f
 
                 if mode == 'rtransfer':
                     dest = self['dest']
@@ -104,8 +108,12 @@ class FileTransferTask(FireTaskBase):
                         sftp.put(src, dest)
 
                 else:
-                    dest = abspath(expanduser(expandvars(self['dest']))) if \
-                        shell_interpret else self['dest']
+                    if 'dest' in f:
+                        dest = abspath(expanduser(expandvars(f['dest']))) if shell_interpret \
+                            else f['dest']
+                    else:
+                        dest = abspath(expanduser(expandvars(self['dest']))) if shell_interpret \
+                            else self['dest']
                     FileTransferTask.fn_list[mode](src, dest)
 
             except:
@@ -124,7 +132,7 @@ class FileTransferTask(FireTaskBase):
         """
         try:
             sftp.stat(path)
-        except IOError, e:
+        except IOError as e:
             if e[0] == 2:
                 return False
             raise
