@@ -25,13 +25,13 @@ class FileWriteDeleteTest(unittest.TestCase):
     def test_run(self):
         t = load_object_from_file(os.path.join(module_dir, "write.yaml"))
         t.run_task({})
-        for i in xrange(2):
+        for i in range(2):
             self.assertTrue(os.path.exists("myfile{}".format(i + 1)))
 
         #Use delete task to remove the files created.
         t = load_object_from_file(os.path.join(module_dir, "delete.yaml"))
         t.run_task({})
-        for i in xrange(2):
+        for i in range(2):
             self.assertFalse(os.path.exists("myfile{}".format(i + 1)))
 
 
